"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = formatDate;
var _convertUtcDateToLocalDateWithSameTime = _interopRequireDefault(require("./convertUtcDateToLocalDateWithSameTime"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }
// Formats a `Date` into a text value provided a `format`
function formatDate(date, format) {
  var _ref = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {},
    utc = _ref.utc;
  // Someone may accidentally pass a timestamp, or a string.
  // Or `date` could be `undefined`.
  if (!(date instanceof Date)) {
    return '';
  }

  // Check if `date` is "Invalid Date".
  if (isNaN(date.getTime())) {
    return '';
  }
  if (utc) {
    date = (0, _convertUtcDateToLocalDateWithSameTime["default"])(date);
  }
  var day = date.getDate();
  var month = date.getMonth() + 1;
  var year = date.getFullYear();
  var text = format.replace('dd', padWithZeroes(String(day), 2)).replace('mm', padWithZeroes(String(month), 2));
  if (text.indexOf('yyyy') >= 0) {
    return text.replace('yyyy', padWithZeroes(String(year), 4));
  }
  if (text.indexOf('yy') >= 0) {
    return text.replace('yy', padWithZeroes(String(year % 100), 2));
  }
}
function padWithZeroes(string, targetLength) {
  while (string.length < targetLength) {
    string = '0' + string;
  }
  return string;
}
//# sourceMappingURL=formatDate.js.map